      subroutine sactphi1(actnn,aphi2,phinn,xmfactor,xla,phi1) 
C Bernd Berg Feb 19 2012.
C Returns scalar action contribution for UPDATE at one site.
C phinn:      Summed up nearest neighboors.
C xmfactor:   Mass term factor (8+m^2)/2 as needed.
C xla:        Coupling of phi**4 term.
C phi1:       Field at the site.
      include '../../Libs/Fortran/implicit.sta'
      include '../../Libs/Fortran/constants.par'
      phi2=phi1**2
      actnn=phinn*phi1
      aphi2=(xmfactor+xla*phi2)*phi2
      ltest=.true.
      ltest=.false.
c     if(ltest) then
c       print*,"phinn,xmfactor,xla,phi1:",phinn,xmfactor,xla,phi1
c     stop "sactphi1: ltest."
c     endif
      return
      end
